Enum AnyDelimiterCodecError
enum AnyDelimiterCodecError
An error occurred while encoding or decoding a chunk.
Variants
-
MaxChunkLengthExceeded The maximum chunk length was exceeded.
-
Io(io::Error) An IO error occurred.
Implementations
impl Debug for AnyDelimiterCodecError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for AnyDelimiterCodecError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for AnyDelimiterCodecError
impl Freeze for AnyDelimiterCodecError
impl From for AnyDelimiterCodecError
fn from(e: Error) -> AnyDelimiterCodecError
impl RefUnwindSafe for AnyDelimiterCodecError
impl Send for AnyDelimiterCodecError
impl Sync for AnyDelimiterCodecError
impl Unpin for AnyDelimiterCodecError
impl UnsafeUnpin for AnyDelimiterCodecError
impl UnwindSafe for AnyDelimiterCodecError
impl<T> Any for AnyDelimiterCodecError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for AnyDelimiterCodecError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for AnyDelimiterCodecError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for AnyDelimiterCodecError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for AnyDelimiterCodecError
fn to_string(self: &Self) -> String
impl<T, U> Into for AnyDelimiterCodecError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for AnyDelimiterCodecError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for AnyDelimiterCodecError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>