Struct WaitForCancellationFutureOwned
struct WaitForCancellationFutureOwned { ... }
A Future that is resolved once the corresponding CancellationToken
is cancelled.
This is the counterpart to WaitForCancellationFuture that takes
CancellationToken by value instead of using a reference.
Implementations
impl Debug for WaitForCancellationFutureOwned
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for WaitForCancellationFutureOwned
impl Future for WaitForCancellationFutureOwned
fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<()>
impl RefUnwindSafe for WaitForCancellationFutureOwned
impl Send for WaitForCancellationFutureOwned
impl Sync for WaitForCancellationFutureOwned
impl UnsafeUnpin for WaitForCancellationFutureOwned
impl UnwindSafe for WaitForCancellationFutureOwned
impl<'__pin> Unpin for WaitForCancellationFutureOwned
impl<F> IntoFuture for WaitForCancellationFutureOwned
fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture
impl<T> Any for WaitForCancellationFutureOwned
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for WaitForCancellationFutureOwned
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for WaitForCancellationFutureOwned
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for WaitForCancellationFutureOwned
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for WaitForCancellationFutureOwned
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for WaitForCancellationFutureOwned
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for WaitForCancellationFutureOwned
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>